pub fn block_height_to_height(
bh: BlockHeight,
) -> Result<Height, SerializationError>Expand description
Returns an error if the height is out of the valid Zebra range.
pub fn block_height_to_height(
bh: BlockHeight,
) -> Result<Height, SerializationError>Returns an error if the height is out of the valid Zebra range.