OrchardBundle

Type Alias OrchardBundle 

type OrchardBundle = Bundle<Authorized, ZatBalance>;
An Orchard-shaped bundle of an authorized transaction, used by both the Orchard and Ironwood pools.

Aliased Type

struct OrchardBundle { /* private fields */ }

Layout

Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.

Size: 1208 bytes